"use strict";
/**
 * Core Services API
 * API covering the [Networking](/iaas/Content/Network/Concepts/overview.htm),
[Compute](/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](/iaas/Content/Block/Concepts/overview.htm) services. Use this API
to manage resources such as virtual cloud networks (VCNs), compute instances, and
block storage volumes.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const models = __importStar(require("./model"));
const oci_common_1 = require("oci-common");
class BlockstorageWaiter {
    constructor(client, workRequestClient, config) {
        this.client = client;
        this.workRequestClient = workRequestClient;
        this.config = config;
    }
    /**
     * Waits forBootVolume till it reaches any of the provided states
     *
     * @param request the request to send
     * @param targetStates the desired states to wait for. The waiter will return once the resource reaches any of the provided states
     * @return response returns GetBootVolumeResponse | null (null in case of 404 response)
     */
    forBootVolume(request, ...targetStates) {
        return __awaiter(this, void 0, void 0, function* () {
            return oci_common_1.genericTerminalConditionWaiter(this.config, () => this.client.getBootVolume(request), response => targetStates.exists(response.bootVolume.lifecycleState), targetStates.includes(models.BootVolume.LifecycleState.TERMINATED));
        });
    }
    /**
     * Waits forBootVolumeBackup till it reaches any of the provided states
     *
     * @param request the request to send
     * @param targetStates the desired states to wait for. The waiter will return once the resource reaches any of the provided states
     * @return response returns GetBootVolumeBackupResponse | null (null in case of 404 response)
     */
    forBootVolumeBackup(request, ...targetStates) {
        return __awaiter(this, void 0, void 0, function* () {
            return oci_common_1.genericTerminalConditionWaiter(this.config, () => this.client.getBootVolumeBackup(request), response => targetStates.exists(response.bootVolumeBackup.lifecycleState), targetStates.includes(models.BootVolumeBackup.LifecycleState.TERMINATED));
        });
    }
    /**
     * Waits forVolume till it reaches any of the provided states
     *
     * @param request the request to send
     * @param targetStates the desired states to wait for. The waiter will return once the resource reaches any of the provided states
     * @return response returns GetVolumeResponse | null (null in case of 404 response)
     */
    forVolume(request, ...targetStates) {
        return __awaiter(this, void 0, void 0, function* () {
            return oci_common_1.genericTerminalConditionWaiter(this.config, () => this.client.getVolume(request), response => targetStates.exists(response.volume.lifecycleState), targetStates.includes(models.Volume.LifecycleState.TERMINATED));
        });
    }
    /**
     * Waits forVolumeBackup till it reaches any of the provided states
     *
     * @param request the request to send
     * @param targetStates the desired states to wait for. The waiter will return once the resource reaches any of the provided states
     * @return response returns GetVolumeBackupResponse | null (null in case of 404 response)
     */
    forVolumeBackup(request, ...targetStates) {
        return __awaiter(this, void 0, void 0, function* () {
            return oci_common_1.genericTerminalConditionWaiter(this.config, () => this.client.getVolumeBackup(request), response => targetStates.exists(response.volumeBackup.lifecycleState), targetStates.includes(models.VolumeBackup.LifecycleState.TERMINATED));
        });
    }
    /**
     * Waits forVolumeGroup till it reaches any of the provided states
     *
     * @param request the request to send
     * @param targetStates the desired states to wait for. The waiter will return once the resource reaches any of the provided states
     * @return response returns GetVolumeGroupResponse | null (null in case of 404 response)
     */
    forVolumeGroup(request, ...targetStates) {
        return __awaiter(this, void 0, void 0, function* () {
            return oci_common_1.genericTerminalConditionWaiter(this.config, () => this.client.getVolumeGroup(request), response => targetStates.exists(response.volumeGroup.lifecycleState), targetStates.includes(models.VolumeGroup.LifecycleState.TERMINATED));
        });
    }
    /**
     * Waits forVolumeGroupBackup till it reaches any of the provided states
     *
     * @param request the request to send
     * @param targetStates the desired states to wait for. The waiter will return once the resource reaches any of the provided states
     * @return response returns GetVolumeGroupBackupResponse | null (null in case of 404 response)
     */
    forVolumeGroupBackup(request, ...targetStates) {
        return __awaiter(this, void 0, void 0, function* () {
            return oci_common_1.genericTerminalConditionWaiter(this.config, () => this.client.getVolumeGroupBackup(request), response => targetStates.exists(response.volumeGroupBackup.lifecycleState), targetStates.includes(models.VolumeGroupBackup.LifecycleState.TERMINATED));
        });
    }
}
exports.BlockstorageWaiter = BlockstorageWaiter;
//# sourceMappingURL=blockstorage-waiter.js.map